<?php

class Mlumen_Option_Page {

	/**
	 * @var Mlumen_Api_Blog
	 */
	private $api_blog;

	/**
	 * @var Mlumen_Options
	 */
	private $api_options;

	/**
	 * @var array
	 */
	private $notification;

	public function __construct( Mlumen_Api_Blog $api_blog, Mlumen_Options $options ) {
		$this->api_blog    = $api_blog;
		$this->api_options = $options;

		add_action( 'admin_menu', array( $this, 'admin_actions' ) );
	}

	/**
	 * Register option page
	 */
	public function admin_actions() {
		add_options_page(
			__( 'mLUMEN - konfiguracja', 'mlumen' ),
			__( 'mLUMEN', 'mlumen' ),
			'manage_options',
			'mlumen',
			array( $this, 'action_options_page' )
		);
	}

	/**
	 * Check permission to update
	 *
	 * @return bool
	 */
	private function check_permission_to_update() {
		return current_user_can( 'manage_options' )
		       && wp_verify_nonce( sanitize_text_field( $_POST['mlumen_nonce_field'] ), 'mlumen_action' );
	}


	/**
	 * Action add blog, change e-mail, delete blog and display activation information
	 */
	public function action_options_page() {
		if ( isset( $_POST['mlumen_submit_add'] ) && $this->check_permission_to_update() ) {

			$email = sanitize_email( $_POST["email"] );

			if ( $this->api_blog->add_blog( $email ) ) {
				$this->api_options->save_options( array(
					'active' => $this->api_blog->data['active'],
					'token'  => $this->api_blog->data['token'],
					'email'  => $this->api_blog->data['email']
				) );
				$this->add_notification( 'success', __( 'Twój blog został dodany do aplikacji mLUMEN', 'mlumen' ) );
			} else {
				$this->add_notification( 'error', $this->api_blog->error_message );
			}

		} elseif ( isset( $_POST['mlumen_submit_edit'] ) && $this->check_permission_to_update() ) {

			$email = sanitize_email( $_POST["email"] );

			if ( $this->api_blog->change_email( $email, $this->api_options->options['token'] ) ) {
				$this->api_options->save_options( [
					'email' => $this->api_blog->data['email']
				] );
				$this->add_notification( 'success', __( 'Adres e-mail powiązany z blogiem został zaaktualizowany', 'mlumen' ) );
			} else {
				$this->add_notification( 'error', $this->api_blog->error_message );
			}

		} elseif ( isset( $_POST['mlumen_submit_delete'] ) && $this->check_permission_to_update() ) {

			if ( $this->api_blog->delete_blog( $this->api_options->options['token'] ) ) {
				$this->api_options->delete_options();
				$this->add_notification( 'success', __( 'Twój blog został usunięty z aplikacji mLUMEN', 'mlumen' ) );
			} else {
				$this->add_notification( 'error', $this->api_blog->error_message );
			}

		} elseif ( isset( $_POST['mlumen_submit_taxonomy'] ) ) {

			$post_create_taxonomy = [];
			if ( isset( $_POST["add_mlumen"] ) && is_array( $_POST["add_mlumen"] ) ) {
				$post_create_taxonomy = array_keys( $_POST["add_mlumen"] );
			}

			$taxonomy_prompts = array();
			if ( isset( $_POST["add_mlumen_prompts"] ) && is_array( $_POST["add_mlumen_prompts"] ) ) {
				$taxonomy_prompts = array_map( static function ( $taxonomy ) {
					return array_keys( (array) $taxonomy );
				}, $_POST["add_mlumen_prompts"] );
			}

			$taxonomy_prompts_type = (int) $_POST["taxonomy_prompts_type"];
			$taxonomy_append       = isset( $_POST["taxonomy_append"] ) && $_POST["taxonomy_append"] == 1;
			$minimal_tags_score    = sanitize_text_field( $_POST["minimal_tags_score"] );
			$limit_tags            = (int) $_POST["limit_tags"];

			if ( $this->api_options->save_options( array(
				'post_create_taxonomy'  => $post_create_taxonomy,
				'taxonomy_prompts'      => $taxonomy_prompts,
				'taxonomy_prompts_type' => $taxonomy_prompts_type,
				'taxonomy_append'       => $taxonomy_append,
				'minimal_tags_score'    => $minimal_tags_score,
				'limit_tags'            => $limit_tags
			) ) ) {
				$this->add_notification( 'success', __( 'Opcje deskryptorów zostały zapisane', 'mlumen' ) );
			} else {
				$this->add_notification( 'error', __( 'Błąd zapisu', 'mlumen' ) );
			}

		} elseif ( isset( $_POST['mlumen_submit_connection'] ) ) {

			$url = get_site_url();
			if ( $this->api_blog->check_connection( $url ) ) {
				$this->add_notification( 'success', __( 'Połączenie do aplikacji mLUMEN jest poprawne', 'mlumen' ) );
			} else {
				$this->add_notification( 'error', $this->api_blog->error_message );
			}

		} elseif ( $this->api_options->options['active'] ) {
			$this->add_notification( 'info', __( 'Twój blog jest aktywny w aplikacji mLUMEN', 'mlumen' ) );

		} else {
			$this->add_notification( 'warning', __( 'Aktywuj bloga w aplikacji mLUMEN', 'mlumen' ) );
		}

		// refresh options
		$this->api_options->load_options();

		$this->display_notification();
		$this->display_page();
	}

	/**
	 * Add notification
	 */
	private function add_notification( string $type, string $message ) {
		$this->notification = array(
			'type'    => $type,
			'message' => $message,
		);
	}

	/**
	 * Display notification
	 */
	private function display_notification() {
		if ( is_null( $this->notification ) ) {
			return;
		}

		?>
        <div class="notice notice-<?php echo esc_attr( $this->notification['type'] ); ?> is-dismissible">
            <p><?php echo esc_html( $this->notification['message'] ); ?></p>
        </div>
		<?php
	}

	/**
	 * Get e-mail current user
	 *
	 * @return string
	 */
	private function get_current_user_email() {
		global $current_user;

		if ( ! ( $current_user instanceof WP_User ) ) {
			return '';
		}

		return $current_user->user_email;
	}

	/**
	 * Get post type
	 *
	 * @return array
	 */
	private function get_post_type() {
		$post_types_mlumen = array();

		$post_types_ignore = array(
			'attachment',
			'wp_block'
		);

		$post_types = get_post_types();
		foreach ( $post_types as $post_type ) {
			if ( in_array( $post_type, $post_types_ignore ) ) {
				continue;
			}

			$post_type_data = get_post_type_object( $post_type );
			if ( isset( $post_type_data ) && $post_type_data->show_ui === false ) {
				continue;
			}

			$post_type_data->taxonomies = array_map( function ( $post_type ) {
				return get_taxonomy( $post_type );
			}, get_taxonomies(
				array( 'object_type' => array( $post_type ) )
			) );

			$post_type_data->taxonomies = array_filter( $post_type_data->taxonomies, function ( $taxonomy ) {

				if ( $taxonomy->hierarchical == 1 ) {
					return false;
				}

				if ( $taxonomy->show_tagcloud != 1 ) {
					return false;
				}

				return true;
			} );

			$post_types_mlumen[] = $post_type_data;
		}

		return $post_types_mlumen;
	}

	/**
	 * Display tooltip
	 */
	private function display_tooltip( $message ) {
        ?>

		<span class="mlumen-tooltip">
            <span class="mlumen-tooltip-icon">i</span>
            <span class="mlumen-tooltip-message"><?php echo esc_html( $message ); ?></span>
		</span>

        <?php
	}

	/**
	 * Template options page
	 */
	private function display_page() {
		$default_tab = null;
		$tab         = isset( $_GET['tab'] ) ? $_GET['tab'] : $default_tab;

		?>
        <div class="wrap mlumen_settings">
            <h1><?php echo esc_html( get_admin_page_title() ); ?></h1>

            <nav class="nav-tab-wrapper">
                <a href="?page=mlumen" class="nav-tab <?php if ( $tab === null ): ?>nav-tab-active<?php endif; ?>">
					<?php _e( 'Aktywacja mLUMEN', 'mlumen' ); ?>
                </a>
                <a href="?page=mlumen&tab=deskryptor"
                   class="nav-tab <?php if ( $tab === 'deskryptor' ): ?>nav-tab-active<?php endif; ?>">
					<?php _e( 'Ustawienia tagów DESKRYPTOR', 'mlumen' ); ?>
                </a>
                <a href="?page=mlumen&tab=help"
                   class="nav-tab <?php if ( $tab === 'help' ): ?>nav-tab-active<?php endif; ?>">
					<?php _e( 'Dokumentacja/FAQ', 'mlumen' ); ?>
                </a>
            </nav>

            <div class="tab-content">
				<?php switch ( $tab ) :
					case 'help':
						$this->tab_page_help();
						break;
					case 'deskryptor':
						$this->tab_page_deskryptor();
						break;
					default:
						$this->tab_page_blog_active();
						break;
				endswitch; ?>
            </div>

        </div>
		<?php
	}

	/**
	 * Display tab with options "Aktywacja mLumen"
	 */
	private function tab_page_blog_active() {
		?>
        <div class="mlumen-options-body metabox-holder columns-2">
            <div id="mlumen-options-form" class="mlumen-options-body-content">
                <form action="" method="post" id="mlumen_form_active" name="mlumen_form_active">
					<?php wp_nonce_field( 'mlumen_action', 'mlumen_nonce_field' ); ?>
                    <table class="form-table">
                        <tbody>
                        <tr>
                            <th rowspan="2" scope="row"><label
                                        for="email"><?php _e( 'Adres e-mail', 'mlumen' ); ?></label>
                            </th>
                            <td>
                                <input type="email" class="regular-text"
                                       value="<?php echo ! empty( $this->api_options->options['email'] ) ? esc_attr( $this->api_options->options['email'] ) : esc_attr( $this->get_current_user_email() ); ?>"
                                       id="email" name="email" placeholder="e-mail" required="required">
                            </td>
                        </tr>
						<?php if ( ! $this->api_options->options['active'] ): ?>
                            <tr>
                                <td>
                                    <label for="accept_rules">
                                        <input name="accept_rules" type="checkbox" id="accept_rules"
                                               value="1" required="required">
                                        <a href="<?php echo esc_url( MLUMEN_RULES_URL ); ?>"
                                           target="_blenk"><?php _e( 'Akceptuję regulamin mLUMEN', 'mlumen' ); ?></a>
                                    </label>
                                </td>
                            </tr>
						<?php endif; ?>
                        </tbody>
                    </table>
                    <p class="submit">
						<?php if ( ! $this->api_options->is_active_blog() ): ?>
                            <input type="submit" value="<?php _e( 'Aktywuj swój blog', 'mlumen' ); ?>"
                                   class="button button-primary" name="mlumen_submit_add">
						<?php else: ?>
                            <input type="submit"
                                   value="<?php _e( 'Zmień kontaktowy adres e-mail', 'mlumen' ); ?>"
                                   class="button button-primary" name="mlumen_submit_edit">
                            <input type="button"
                                   value="<?php _e( 'Usuń bloga z aplikacji mLUMEN', 'mlumen' ); ?>"
                                   class="button button-primary button-color-delete" id="submit_delete">
						<?php endif; ?>
                        <input type="submit"
                               value="<?php _e( 'Testuj połączenie', 'mlumen' ); ?>"
                               class="button button-primary"
                               id="mlumen_submit_connection"
                               name="mlumen_submit_connection">
                    </p>
                </form>
            </div>
            <div id="mlumen-options-delete-ask" class="notice notice-error mlumen-options-delete-ask">
                <form action="" method="post" name="mlumen_form">
					<?php wp_nonce_field( 'mlumen_action', 'mlumen_nonce_field' ); ?>
                    <p>
						<?php _e( 'Czy na pewno chcesz usunąć blog z aplikacji mLUMEN?', 'mlumen' ); ?>
                    </p>
                    <p class="submit">
                        <input type="submit"
                               value="<?php _e( 'Usuń', 'mlumen' ); ?>"
                               class="button button-primary button-color-delete"
                               id="mlumen_submit_delete"
                               name="mlumen_submit_delete">

                        <input type="button"
                               value="<?php _e( 'Anuluj', 'mlumen' ); ?>"
                               class="button button-primary"
                               id="cancel_delete"
                               name="cancel_delete">
                    </p>
                </form>
            </div>
        </div>
		<?php
	}

	/**
	 * Display tab with options "Tagi mLumen"
	 */
	private function tab_page_deskryptor() {
		?>
        <div class="mlumen-options-body metabox-holder columns-2">
            <div id="mlumen-options-form" class="mlumen-options-body-content">
                <form action="" method="post" name="mlumen_form">
					<?php wp_nonce_field( 'mlumen_action', 'mlumen_nonce_field' ); ?>

                    <h3><?php _e( 'Dodaj tagi DBN do istniejących taksonomii', 'mlumen' ); ?></h3>
					<?php foreach ( $this->get_post_type() as $post_type ): ?>
						<?php foreach ( $post_type->taxonomies as $taxonomy ):
							if ( substr( $taxonomy->name, - 7 ) === '_mlumen' ) {
								continue;
							}
							?>
                            <label for="add_mlumen_<?php echo esc_attr( $post_type->name ); ?>_<?php echo esc_attr( $taxonomy->name ); ?>">
                                <input name="add_mlumen_prompts[<?php echo esc_attr( $post_type->name ); ?>][<?php echo esc_attr( $taxonomy->name ); ?>]"
                                       type="checkbox"
                                       id="add_mlumen_<?php echo esc_attr( $post_type->name ); ?>_<?php echo esc_attr( $taxonomy->name ); ?>"
									<?php echo isset( $this->api_options->options['taxonomy_prompts'][ $post_type->name ] ) &&
									           in_array( $taxonomy->name, $this->api_options->options['taxonomy_prompts'][ $post_type->name ] ) ? ' checked="checked"' : ''; ?>
                                       value="1">

								<?php echo sprintf(
                                    // translators: %s: number of tags added, %s: number of all tags
									__( 'dodaj "<b>Tagi DBN</b>" do istniejącej taksonomii "<b>%1$s</b>" przy "<b>%2$s</b>"', 'mlumen' ),
									esc_html( $taxonomy->label ),
									esc_html( $post_type->labels->name )
								);
								?>

								<?php if ( $taxonomy->name == 'post_tag' ): ?>
                                    <b><?php _e( '(zalecane)', 'mlumen' ); ?></b>
								<?php endif; ?>
								<?php $this->display_tooltip(
									__( 'Zaznacz tę opcję, jeśli chcesz, żeby tagi DBN pojawiały się w tym samym miejscu i działały w ten sam sposób, co Twoje dotychczasowe tagi. Jest to opcja zalecana większości użytkownikom.', 'mlumen' )
								); ?>
                            </label>
						<?php endforeach; ?>
					<?php endforeach; ?>

                    <h3><?php _e( 'Utwórz nowe taksonomie', 'mlumen' ); ?></h3>
					<?php foreach ( $this->get_post_type() as $post_type ): ?>
                        <label for="add_mlumen_<?php echo esc_attr( $post_type->name ); ?>">
                            <input name="add_mlumen[<?php echo esc_attr( $post_type->name ); ?>]"
                                   type="checkbox"
                                   id="add_mlumen_<?php echo esc_attr( $post_type->name ); ?>"
								<?php echo in_array( $post_type->name, $this->api_options->options['post_create_taxonomy'] ) ? ' checked="checked"' : ''; ?>
                                   value="1">
							<?php echo sprintf(
							    // translators: %s: post type label
								__( 'utwórz nową taksonomię "<b>Tagi DBN</b>" przy <b>"%s"</b> i dodaj do niej tagi', 'mlumen' ),
								esc_html( $post_type->labels->name )
							);
							?>
                        </label>
                        <br>
					<?php endforeach; ?>

                    <h3><label for="minimal_tags_score"><?php _e( 'Sposób dodawania tagów: ', 'mlumen' ); ?></label>
                    </h3>
                    <input name="taxonomy_prompts_type" id="taxonomy_prompts_type_1" type="radio"
                           value="1" <?php echo $this->api_options->options['taxonomy_prompts_type'] == 1 ? ' checked="checked"' : ''; ?> />
                    <label for="taxonomy_prompts_type_1"><?php _e( ' ręczny wybór pojedynczych tagów ', 'mlumen' ); ?></label>
                    <br>
                    <input name="taxonomy_prompts_type" id="taxonomy_prompts_type_2" type="radio"
                           value="2" <?php echo $this->api_options->options['taxonomy_prompts_type'] == 2 ? ' checked="checked"' : ''; ?> />
                    <label for="taxonomy_prompts_type_2"><?php _e( ' automatyczne dodawanie tagów jednym kliknięciem ', 'mlumen' ); ?>
                        <b><?php _e( '(zalecane)', 'mlumen' ); ?></b></label>
					<?php $this->display_tooltip(
						__( 'Zaznacz tę opcję, jeśli chcesz mieć możliwość dodania zestawu tagów DBN za pomocą jednego przycisku podczas edycji/dodawania wpisu. Jest to opcja zalecana większości użytkownikom.', 'mlumen' )
					); ?>
                    <br>
                    <input name="taxonomy_prompts_type" id="taxonomy_prompts_type_3" type="radio"
                           value="3" <?php echo $this->api_options->options['taxonomy_prompts_type'] == 3 ? ' checked="checked"' : ''; ?> />
                    <label for="taxonomy_prompts_type_3"><?php _e( ' automatyczne dodawanie tagów podczas zapisu wpisów (postów) ', 'mlumen' ); ?></label>

                    <h3><label for="minimal_tags_score"><?php _e( 'Sposób zapisu:', 'mlumen' ); ?></label></h3>
                    <select id="taxonomy_append"
                            name="taxonomy_append" <?php echo ( $this->api_options->options['taxonomy_prompts_type'] == 1 || $this->api_options->options['taxonomy_prompts_type'] == 2 ) ? ' disabled="disabled"' : ''; ?>>
                        <option value="1"<?php echo $this->api_options->options['taxonomy_append'] ? ' selected="selected"' : ''; ?>><?php _e( 'dodaj do istniejących tagów', 'mlumen' ); ?></option>
                        <option value="0"<?php echo ! $this->api_options->options['taxonomy_append'] ? ' selected="selected"' : ''; ?>><?php _e( 'zastąp istniejące tagi', 'mlumen' ); ?></option>
                    </select>

                    <h3>
                        <label for="minimal_tags_score"><?php _e( 'Minimalny próg trafności tagów:', 'mlumen' ); ?></label>
                    </h3>
                    <input name="minimal_tags_score"
                           type="text"
                           id="minimal_tags_score"
                           pattern="0\.\d+"
                           value="<?php echo esc_attr( $this->api_options->options['minimal_tags_score'] ); ?>"
                           style="width:100px"
                    >
					<?php $this->display_tooltip(
						__( 'Podczas pobierania tagów każdy z nich opatrywany jest wartością z zakresu 0-1, wyznaczającą poziom prawdopodobieństwa trafności danego tagu. Wartością zalecaną, od której tag ma zostać dodany do Twojego wpisu, jest 0.05 (już od tego poziomu tagi są w większości przypadków wiarygodne).', 'mlumen' )
					); ?>

                    <h3><label for="limit_tags"><?php _e( 'Liczba pobieranych tagów:', 'mlumen' ); ?></label></h3>
                    <input name="limit_tags"
                           type="number"
                           id="limit_tags"
                           min="1"
                           max="25"
                           value="<?php echo esc_attr( $this->api_options->options['limit_tags'] ); ?>"
                           style="width:100px">

                    <p class="submit">
                        <input type="submit" value="<?php _e( 'Zapisz', 'mlumen' ); ?>"
                               class="button button-primary" name="mlumen_submit_taxonomy">
                    </p>
                </form>
            </div>
        </div>
		<?php
	}

	/**
	 * Display tab with options "Dokumentacja/FAQ"
	 */
	private function tab_page_help() {
		?>
        <div class="mlumen-options-body metabox-holder columns-3">
            <div class="mlumen-options-body-content">
                <p><?php _e( 'Wtyczka umożliwia automatyczne tagowanie treści wpisów przy użyciu Deskryptorów Biblioteki Narodowej (DBN) i e-usługi DESKRYPTOR. Integracja bloga/portalu z agregatorem treści (aplikacją mobilną mLUMEN) stworzonym przez Bibliotekę Narodową.', 'mlumen' ); ?></p>
                <p><?php _e( 'Projekt jest realizowany w ramach Działania 2.4 „Tworzenie usług i aplikacji wykorzystujących e-usługi publiczne i informacje sektora publicznego” II osi priorytetowej „E-administracja i otwarty rząd” Programu Operacyjnego Polska Cyfrowa. Pozostałą część dofinansowano ze środków Ministra Kultury i Dziedzictwa Narodowego.', 'mlumen' ); ?></p>
                <p><img src="<?php echo MLUMEN_PLUGIN_URL . 'admin/images/ue.png'; ?>" class="mlumen-ue" alt="<?php _e('Projekt jest realizowany w ramach Działania 2.4 „Tworzenie usług i aplikacji wykorzystujących e-usługi publiczne i informacje sektora publicznego” II osi priorytetowej „E-administracja i otwarty rząd” Programu Operacyjnego Polska Cyfrowa. Pozostałą część dofinansowano ze środków Ministra Kultury i Dziedzictwa Narodowego.'); ?>" /></p>

                <h3 class="mlumen-faq-title"><?php _e( 'Czym jest aplikacja mLUMEN?', 'mlumen' ); ?></h3>
                <p class="mlumen-faq-content"><?php _e( 'mLUMEN to aplikacja mobilna prezentująca użytkownikom zagregowane zbiory polskich bibliotek, dane instytucji publicznych oraz wpisy (posty) blogów i serwisów internetowych. Jej celem jest zebranie w jednym miejscu informacji o interesujących użytkownika “tematach”. Dzięki temu użytkownik będzie mógł za jednym kliknięciem odnaleźć ważne dla niego informacje niezależnie od tego, w jakiej formie zostały opublikowane.', 'mlumen' ); ?></p>

                <h3 class="mlumen-faq-title"><?php _e( 'Co zyska mój blog po podpięciu do mLUMEN?', 'mlumen' ); ?></h3>
                <p class="mlumen-faq-content"><?php _e( 'Dzięki podłączeniu do aplikacji mobilnej mLUMEN zwiększy się wyszukiwalność wpisów zamieszczanych na blogach, co pośrednio przełoży się także na zwiększenie liczby czytelników bloga. Ponadto dzięki zastosowaniu e-usługi DESKRYPTOR twórca treści będzie miał możliwość automatycznego otagowania swojego wpisu przy pomocy ujednoliconych tagów (słów kluczowych), opartych na Deskryptorach Biblioteki Narodowej.', 'mlumen' ); ?></p>

                <h3 class="mlumen-faq-title"><?php _e( 'Czy po podłączeniu bloga aplikacja mobilna mLUMEN będzie przekierowywać bezpośrednio do wpisów na blogu?', 'mlumen' ); ?></h3>
                <p class="mlumen-faq-content"><?php _e( 'Tak. W aplikacji mobilnej mLUMEN będą prezentowane informacje dotyczące samego wpisu (data publikacji wpisu), jego źródło oraz skrócony początek (streszczenie), który ułatwi użytkownikom zainteresowanie się daną treścią. Natomiast żeby zapoznać się z całym wpisem, użytkownik będzie musiał przejść bezpośrednio do źródła za pomocą zamieszczonego linku.', 'mlumen' ); ?></p>

                <h3 class="mlumen-faq-title"><?php _e( 'Czy udział w projekcie mLUMEN jest płatny?', 'mlumen' ); ?></h3>
                <p class="mlumen-faq-content"><?php _e( 'Udział w projekcie mLUMEN jest i pozostanie bezpłatny zarówno dla użytkowników aplikacji, jak i dla osób chcących podłączyć swoje blogi do aplikacji w ramach projektu.', 'mlumen' ); ?></p>

                <h3 class="mlumen-faq-title"><?php _e( 'Co muszę zrobić, by podpiąć swój blog lub portal do aplikacji mLUMEN?', 'mlumen' ); ?></h3>
                <p class="mlumen-faq-content"><?php _e( 'Aby podłączyć się do aplikacji mobilnej mLUMEN należy zainstalować wtyczkę mLUMEN i aktywować blog. Po jej podłączeniu aplikacja mobilna mLUMEN będzie automatycznie pobierać wszystkie wpisy, które będą następnie automatycznie tagowane oraz udostępniane w aplikacji. Dodatkowo wtyczka będzie umożliwiać automatyczne dodanie Deskryptorów Biblioteki Narodowej jako tagów w systemie Wordpress. Twórca treści oprócz jednorazowego działania polegającego na instalacji wtyczki, nie będzie musiał w żaden sposób nadzorować przesyłania danych dotyczących wpisu.', 'mlumen' ); ?></p>

                <h3 class="mlumen-faq-title"><?php _e( 'Czy instalacja wtyczki mLUMEN będzie znacząco spowalniać działanie mojej strony lub obciążać serwer?', 'mlumen' ); ?></h3>
                <p class="mlumen-faq-content"><?php _e( 'Wtyczka mLUMEN będzie miała minimalny wpływ na szybkość działania strony i nie będzie obciążała serwera. Po instalacji wtyczki aplikacja mobilna mLUMEN jednorazowo pobierze wszystkie wpisy przy pomocy REST API systemu Wordpress, a następnie cyklicznie będzie sprawdzać, czy pojawiły się nowe wpisy (posty). Dzięki wykorzystaniu REST API pobierana będzie minimalna ilość danych (wyłącznie dane tekstowe i metadane wpisów, bez obrazów). Z naszych testów wynika, że pobranie w ten sposób nawet wielu tysięcy postów zajmuje jedynie kilka-kilkanaście sekund.', 'mlumen' ); ?></p>

                <h3 class="mlumen-faq-title"><?php _e( 'Jakie treści będą zamieszczane w aplikacji mLUMEN?', 'mlumen' ); ?></h3>
                <p class="mlumen-faq-content"><?php _e( 'Aplikacja mobilna mLUMEN będzie zawierać treści związane z zawartością zbiorów polskich bibliotek, zestawów danych publicznych zamieszczonych w serwisie dane.gov.pl oraz wpisów (postów) polskich blogów i serwisów internetowych opartych na systemie zarządzania treścią WordPress.', 'mlumen' ); ?></p>

                <h3 class="mlumen-faq-title"><?php _e( 'Jaka jest grupa docelowa użytkowników aplikacji?', 'mlumen' ); ?></h3>
                <p class="mlumen-faq-content"><?php _e( 'Grupą docelową użytkowników aplikacji są osoby w przedziale wiekowym od 18 do 44 lat.', 'mlumen' ); ?></p>

                <h3 class="mlumen-faq-title"><?php _e( 'Czy mam wpływ na pozycjonowanie treści z mojego bloga w aplikacji mLUMEN?', 'mlumen' ); ?></h3>
                <p class="mlumen-faq-content"><?php _e( 'Wszystkie treści w aplikacji mobilnej mLUMEN traktowane są równorzędnie.', 'mlumen' ); ?><br></p>

                <h3 class="mlumen-faq-title"><?php _e( 'Czy mogę usunąć swój blog z aplikacji?', 'mlumen' ); ?></h3>
                <p class="mlumen-faq-content"><?php _e( 'Tak. W przypadku chęci zakończenia udostępniania treści ze swojego blogu w aplikacji mobilnej mLUMEN, będzie dowolnym momencie będzie można usunąć swój blog.', 'mlumen' ); ?></p>

                <h3 class="mlumen-faq-title"><?php _e( 'Czy w aplikacji mLUMEN będą zamieszczane reklamy?', 'mlumen' ); ?></h3>
                <p class="mlumen-faq-content"><?php _e( 'Nie, aplikacja mLUMEN będzie wolna od komercyjnych reklam.', 'mlumen' ); ?></p>
            </div>
        </div>
		<?php
	}
}